Author: fireball
Date: Mon Jul 28 06:32:04 2008
New Revision: 34898
URL:
http://svn.reactos.org/svn/reactos?rev=34898&view=rev
Log:
- Update syscall table to completely match win2003sp1.
- Add missing stubs.
Added:
branches/nwin32/subsystems/win32/win32k/include/stubs.h (with props)
branches/nwin32/subsystems/win32/win32k/ntuser/usrfuncs.c (with props)
Modified:
branches/nwin32/subsystems/win32/win32k/include/win32k.h
branches/nwin32/subsystems/win32/win32k/ntddraw/ddeng.c
branches/nwin32/subsystems/win32/win32k/ntgdi/gdifuncs.c
branches/nwin32/subsystems/win32/win32k/ntgdi/gdistubs.c
branches/nwin32/subsystems/win32/win32k/ntuser/usrstubs.c
branches/nwin32/subsystems/win32/win32k/w32ksvc.db
branches/nwin32/subsystems/win32/win32k/win32k.rbuild
branches/nwin32/subsystems/win32/win32k/win32k_vc9.vcproj
Added: branches/nwin32/subsystems/win32/win32k/include/stubs.h
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/include/stubs.h (added)
+++ branches/nwin32/subsystems/win32/win32k/include/stubs.h [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -1,0 +1,13 @@
+/*
+ * COPYRIGHT: See COPYING in the top level directory
+ * PROJECT: ReactOS Win32K
+ * FILE: subsystems/win32/win32k/include/stubs.h
+ * PURPOSE: Stubs declared here, temp header
+ * PROGRAMMER: Aleksey Bragin (aleksey(a)reactos.org)
+ */
+
+/* INCLUDES ******************************************************************/
+
+W32KAPI VOID APIENTRY UMPDDrvQuerySpoolType(DWORD Param1, DWORD Param2);
+W32KAPI VOID APIENTRY DefaultHTCallBack(DWORD Param1);
+VOID APIENTRY DxEngGetRedirectionBitmap(DWORD Param1); // -> dxeng.h
Propchange: branches/nwin32/subsystems/win32/win32k/include/stubs.h
------------------------------------------------------------------------------
svn:eol-style = native
Modified: branches/nwin32/subsystems/win32/win32k/include/win32k.h
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/include/win32k.h [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/include/win32k.h [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -72,3 +72,6 @@
#include <win32k/ntgdityp.h>
#define LANGPACK
#include <psdk/ntgdi.h>
+
+/* Stubbed function declarations */
+#include <stubs.h>
Modified: branches/nwin32/subsystems/win32/win32k/ntddraw/ddeng.c
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/ntddraw/ddeng.c [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/ntddraw/ddeng.c [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -77,3 +77,10 @@
UNIMPLEMENTED;
return FALSE;
}
+
+VOID
+APIENTRY
+DxEngGetRedirectionBitmap(DWORD Param1)
+{
+ UNIMPLEMENTED;
+}
Modified: branches/nwin32/subsystems/win32/win32k/ntgdi/gdifuncs.c
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/ntgdi/gdistubs.c [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/ntgdi/gdistubs.c [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -857,13 +857,6 @@
) { UNIMPLEMENTED; }
W32KAPI
-HANDLE
-APIENTRY
-NtGdiGetStockObject(
- IN INT iObject
-) { UNIMPLEMENTED; }
-
-W32KAPI
HBITMAP
APIENTRY
NtGdiCreateCompatibleBitmap(
@@ -1277,13 +1270,6 @@
IN OPTIONAL LPWSTR lpBaseFaceName,
IN ULONG cwcBaseFaceName,
IN BOOL bSystemTimeStamp
-) { UNIMPLEMENTED; }
-
-W32KAPI
-ULONG
-APIENTRY
-NtGdiQueryFontAssocInfo(
- IN HDC hdc
) { UNIMPLEMENTED; }
#if (_WIN32_WINNT >= 0x0500)
@@ -3634,3 +3620,19 @@
NtGdiEndPath(
IN HDC hdc
) { UNIMPLEMENTED; }
+
+W32KAPI
+VOID
+APIENTRY
+UMPDDrvQuerySpoolType(DWORD Param1, DWORD Param2)
+{
+ UNIMPLEMENTED;
+}
+
+W32KAPI
+VOID
+APIENTRY
+DefaultHTCallBack(DWORD Param1)
+{
+ UNIMPLEMENTED;
+}
Added: branches/nwin32/subsystems/win32/win32k/ntuser/usrfuncs.c
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/ntuser/usrfuncs.c (added)
+++ branches/nwin32/subsystems/win32/win32k/ntuser/usrfuncs.c [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -1,0 +1,26 @@
+/*
+ * PROJECT: ReactOS Win32K
+ * LICENSE: GPL - See COPYING in the top level directory
+ * FILE: subsystems/win32/win32k/ntuser/usrfuncs.c
+ * PURPOSE: User functions
+ * PROGRAMMERS: Aleksey Bragin (aleksey(a)reactos.org)
+ */
+
+/* INCLUDES ******************************************************************/
+
+#include <win32k.h>
+#define NDEBUG
+#include <debug.h>
+
+/* PUBLIC FUNCTIONS **********************************************************/
+
+DWORD
+NTAPI
+NtUserGetThreadState(DWORD ThreadState)
+{
+ DPRINT1("NtUserGetThreadState() ThreadState %d\n", ThreadState);
+
+ /* TODO: A big switch-case for all possible threadstate requires */
+ return 0;
+}
+
Propchange: branches/nwin32/subsystems/win32/win32k/ntuser/usrfuncs.c
------------------------------------------------------------------------------
svn:eol-style = native
Modified: branches/nwin32/subsystems/win32/win32k/ntuser/usrstubs.c
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/ntuser/usrstubs.c [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/ntuser/usrstubs.c [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -718,7 +718,21 @@
PUNICODE_STRING ClassName,
LPWNDCLASSEXW wcex,
LPWSTR *ppszMenuName,
- BOOL Ansi) { UNIMPLEMENTED; }
+ BOOL Ansi)
+{
+ UNIMPLEMENTED;
+ return FALSE;
+}
+
+BOOL
+NTAPI
+NtUserGetClassInfoEx(DWORD Param1, DWORD Param2,
+ DWORD Param3, DWORD Param4,
+ DWORD Param5)
+{
+ UNIMPLEMENTED;
+ return FALSE;
+}
INT
NTAPI
@@ -1013,11 +1027,6 @@
NtUserGetThreadDesktop(
DWORD dwThreadId,
DWORD Unknown1) { UNIMPLEMENTED; }
-
-DWORD
-NTAPI
-NtUserGetThreadState(
- DWORD Routine) { UNIMPLEMENTED; }
BOOLEAN
NTAPI
Modified: branches/nwin32/subsystems/win32/win32k/w32ksvc.db
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/w32ksvc.db [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/w32ksvc.db [iso-8859-1] Mon Jul 28 06:32:04
2008
@@ -1,670 +1,669 @@
-NtGdiAbortDoc 1
-NtGdiAbortPath 1
-NtGdiAddFontResourceW 6
-NtGdiAddRemoteFontToDC 4
-NtGdiAddFontMemResourceEx 5
-NtGdiRemoveMergeFont 2
-NtGdiAddRemoteMMInstanceToDC 3
-NtGdiAlphaBlend 12
-NtGdiAngleArc 6
-NtGdiAnyLinkedFonts 0
-NtGdiFontIsLinked 1
-NtGdiArcInternal 10
-NtGdiBeginPath 1
-NtGdiBitBlt 11
-NtGdiCancelDC 1
-NtGdiCheckBitmapBits 8
-NtGdiCloseFigure 1
-NtGdiClearBitmapAttributes 2
-NtGdiClearBrushAttributes 2
-NtGdiColorCorrectPalette 6
-NtGdiCombineRgn 4
-NtGdiCombineTransform 3
-NtGdiComputeXformCoefficients 1
-NtGdiConsoleTextOut 4
-NtGdiConvertMetafileRect 2
-NtGdiCreateBitmap 5
-NtGdiCreateClientObj 1
-NtGdiCreateColorSpace 1
-NtGdiCreateColorTransform 8
-NtGdiCreateCompatibleBitmap 3
-NtGdiCreateCompatibleDC 1
-NtGdiCreateDIBBrush 6
-NtGdiCreateDIBitmapInternal 11
-NtGdiCreateDIBSection 9
-NtGdiCreateEllipticRgn 4
-NtGdiCreateHalftonePalette 1
-NtGdiCreateHatchBrushInternal 3
-NtGdiCreateMetafileDC 1
-NtGdiCreatePaletteInternal 2
-NtGdiCreatePatternBrushInternal 3
-NtGdiCreatePen 4
-NtGdiCreateRectRgn 4
-NtGdiCreateRoundRectRgn 6
-NtGdiCreateServerMetaFile 6
-NtGdiCreateSolidBrush 2
-NtGdiD3dContextCreate 4
-NtGdiD3dContextDestroy 1
-NtGdiD3dContextDestroyAll 1
-NtGdiD3dValidateTextureStageState 1
-NtGdiD3dDrawPrimitives2 7
-NtGdiDdGetDriverState 1
-NtGdiDdAddAttachedSurface 3
-NtGdiDdAlphaBlt 3
-NtGdiDdAttachSurface 2
-NtGdiDdBeginMoCompFrame 2
-NtGdiDdBlt 3
-NtGdiDdCanCreateSurface 2
-NtGdiDdCanCreateD3DBuffer 2
-NtGdiDdColorControl 2
-NtGdiDdCreateDirectDrawObject 1
-NtGdiDdCreateSurface 8
-NtGdiDdCreateD3DBuffer 8
-NtGdiDdCreateMoComp 2
-NtGdiDdCreateSurfaceObject 6
-NtGdiDdDeleteDirectDrawObject 1
-NtGdiDdDeleteSurfaceObject 1
-NtGdiDdDestroyMoComp 2
-NtGdiDdDestroySurface 2
-NtGdiDdDestroyD3DBuffer 1
-NtGdiDdEndMoCompFrame 2
-NtGdiDdFlip 5
-NtGdiDdFlipToGDISurface 2
-NtGdiDdGetAvailDriverMemory 2
-NtGdiDdGetBltStatus 2
-NtGdiDdGetDC 2
-NtGdiDdGetDriverInfo 2
-NtGdiDdGetDxHandle 3
-NtGdiDdGetFlipStatus 2
-NtGdiDdGetInternalMoCompInfo 2
-NtGdiDdGetMoCompBuffInfo 2
-NtGdiDdGetMoCompGuids 2
-NtGdiDdGetMoCompFormats 2
-NtGdiDdGetScanLine 2
-NtGdiDdLock 3
-NtGdiDdLockD3D 2
-NtGdiDdQueryDirectDrawObject 11
-NtGdiDdQueryMoCompStatus 2
-NtGdiDdReenableDirectDrawObject 2
-NtGdiDdReleaseDC 1
-NtGdiDdRenderMoComp 2
-NtGdiDdResetVisrgn 2
-NtGdiDdSetColorKey 2
-NtGdiDdSetExclusiveMode 2
-NtGdiDdSetGammaRamp 3
-NtGdiDdCreateSurfaceEx 3
-NtGdiDdSetOverlayPosition 3
-NtGdiDdUnattachSurface 2
-NtGdiDdUnlock 2
-NtGdiDdUnlockD3D 2
-NtGdiDdUpdateOverlay 3
-NtGdiDdWaitForVerticalBlank 2
-NtGdiDvpCanCreateVideoPort 2
-NtGdiDvpColorControl 2
-NtGdiDvpCreateVideoPort 2
-NtGdiDvpDestroyVideoPort 2
-NtGdiDvpFlipVideoPort 4
-NtGdiDvpGetVideoPortBandwidth 2
-NtGdiDvpGetVideoPortField 2
-NtGdiDvpGetVideoPortFlipStatus 2
-NtGdiDvpGetVideoPortInputFormats 2
-NtGdiDvpGetVideoPortLine 2
-NtGdiDvpGetVideoPortOutputFormats 2
-NtGdiDvpGetVideoPortConnectInfo 2
-NtGdiDvpGetVideoSignalStatus 2
-NtGdiDvpUpdateVideoPort 4
-NtGdiDvpWaitForVideoPortSync 2
-NtGdiDvpAcquireNotification 3
-NtGdiDvpReleaseNotification 2
-NtGdiDxgGenericThunk 6
-NtGdiDeleteClientObj 1
-NtGdiDeleteColorSpace 1
-NtGdiDeleteColorTransform 2
-NtGdiDeleteObjectApp 1
-NtGdiDescribePixelFormat 4
-NtGdiGetPerBandInfo 2
-NtGdiDoBanding 4
-NtGdiDoPalette 6
-NtGdiDrawEscape 4
-NtGdiEllipse 5
-NtGdiEnableEudc 1
-NtGdiEndDoc 1
-NtGdiEndPage 1
-NtGdiEndPath 1
-NtGdiEnumFontChunk 5
-NtGdiEnumFontClose 1
-NtGdiEnumFontOpen 7
-NtGdiEnumObjects 4
-NtGdiEqualRgn 2
-NtGdiEudcLoadUnloadLink 7
-NtGdiExcludeClipRect 5
-NtGdiExtCreatePen 11
-NtGdiExtCreateRegion 3
-NtGdiExtEscape 8
-NtGdiExtFloodFill 5
-NtGdiExtGetObjectW 3
-NtGdiExtSelectClipRgn 3
-NtGdiExtTextOutW 9
-NtGdiFillPath 1
-NtGdiFillRgn 3
-NtGdiFlattenPath 1
-NtGdiFlush 0
-NtGdiForceUFIMapping 2
-NtGdiFrameRgn 5
-NtGdiFullscreenControl 5
-NtGdiGetAndSetDCDword 4
-NtGdiGetAppClipBox 2
-NtGdiGetBitmapBits 3
-NtGdiGetBitmapDimension 2
-NtGdiGetBoundsRect 3
-NtGdiGetCharABCWidthsW 6
-NtGdiGetCharacterPlacementW 6
-NtGdiGetCharSet 1
-NtGdiGetCharWidthW 6
-NtGdiGetCharWidthInfo 2
-NtGdiGetColorAdjustment 2
-NtGdiGetColorSpaceforBitmap 1
-NtGdiGetDCDword 3
-NtGdiGetDCforBitmap 1
-NtGdiGetDCObject 2
-NtGdiGetDCPoint 3
-NtGdiGetDeviceCaps 2
-NtGdiGetDeviceGammaRamp 2
-NtGdiGetDeviceCapsAll 2
-NtGdiGetDIBitsInternal 9
-NtGdiGetETM 2
-NtGdiGetEudcTimeStampEx 3
-NtGdiGetFontData 5
-NtGdiGetFontResourceInfoInternalW 7
-NtGdiGetGlyphIndicesW 5
-NtGdiGetGlyphIndicesWInternal 6
-NtGdiGetGlyphOutline 8
-NtGdiGetKerningPairs 3
-NtGdiGetLinkedUFIs 3
-NtGdiGetMiterLimit 2
-NtGdiGetMonitorID 3
-NtGdiGetNearestColor 2
-NtGdiGetNearestPaletteIndex 2
-NtGdiGetObjectBitmapHandle 2
-NtGdiGetOutlineTextMetricsInternalW 4
-NtGdiGetPath 4
-NtGdiGetPixel 3
-NtGdiGetRandomRgn 3
-NtGdiGetRasterizerCaps 2
-NtGdiGetRealizationInfo 3
-NtGdiGetRegionData 3
-NtGdiGetRgnBox 2
-NtGdiGetServerMetaFileBits 7
-NtGdiGetSpoolMessage 4
-NtGdiGetStats 5
-NtGdiGetStockObject 1
-NtGdiGetStringBitmapW 5
-NtGdiGetSystemPaletteUse 1
-NtGdiGetTextCharsetInfo 3
-NtGdiGetTextExtent 5
-NtGdiGetTextExtentExW 8
-NtGdiGetTextFaceW 4
-NtGdiGetTextMetricsW 3
-NtGdiGetTransform 3
-NtGdiGetUFI 6
-NtGdiGetEmbUFI 7
-NtGdiGetUFIPathname 10
-NtGdiGetEmbedFonts 0
-NtGdiChangeGhostFont 2
-NtGdiAddEmbFontToDC 2
-NtGdiGetFontUnicodeRanges 2
-NtGdiGetWidthTable 7
-NtGdiGradientFill 6
-NtGdiHfontCreate 5
-NtGdiIcmBrushInfo 8
-NtGdiInit 0
-NtGdiInitSpool 0
-NtGdiIntersectClipRect 5
-NtGdiInvertRgn 2
-NtGdiLineTo 3
-NtGdiMakeFontDir 5
-NtGdiMakeInfoDC 2
-NtGdiMaskBlt 13
-NtGdiModifyWorldTransform 3
-NtGdiMonoBitmap 1
-NtGdiMoveTo 4
-NtGdiOffsetClipRgn 3
-NtGdiOffsetRgn 3
-NtGdiOpenDCW 7
-NtGdiPatBlt 6
-NtGdiPolyPatBlt 5
-NtGdiPathToRegion 1
-NtGdiPlgBlt 11
-NtGdiPolyDraw 4
-NtGdiPolyPolyDraw 5
-NtGdiPolyTextOutW 4
-NtGdiPtInRegion 3
-NtGdiPtVisible 3
-NtGdiQueryFonts 3
-NtGdiQueryFontAssocInfo 1
-NtGdiRectangle 5
-NtGdiRectInRegion 2
-NtGdiRectVisible 2
-NtGdiRemoveFontResourceW 6
-NtGdiRemoveFontMemResourceEx 1
-NtGdiResetDC 5
-NtGdiResizePalette 2
-NtGdiRestoreDC 2
-NtGdiRoundRect 7
-NtGdiSaveDC 1
-NtGdiScaleViewportExtEx 6
-NtGdiScaleWindowExtEx 6
-NtGdiSelectBitmap 2
-NtGdiSelectBrush 2
-NtGdiSelectClipPath 2
-NtGdiSelectFont 2
-NtGdiSelectPen 2
-NtGdiSetBitmapAttributes 2
-NtGdiSetBitmapBits 3
-NtGdiSetBitmapDimension 4
-NtGdiSetBoundsRect 3
-NtGdiSetBrushAttributes 2
-NtGdiSetBrushOrg 4
-NtGdiSetColorAdjustment 2
-NtGdiSetColorSpace 2
-NtGdiSetDeviceGammaRamp 2
-NtGdiSetDIBitsToDeviceInternal 16
-NtGdiSetFontEnumeration 1
-NtGdiSetFontXform 3
-NtGdiSetIcmMode 3
-NtGdiSetLinkedUFIs 3
-NtGdiSetMagicColors 3
-NtGdiSetMetaRgn 1
-NtGdiSetMiterLimit 3
-NtGdiGetDeviceWidth 1
-NtGdiMirrorWindowOrg 1
-NtGdiSetLayout 3
-NtGdiSetPixel 4
-NtGdiSetPixelFormat 2
-NtGdiSetRectRgn 5
-NtGdiSetSystemPaletteUse 2
-NtGdiSetTextJustification 3
-NtGdiSetupPublicCFONT 3
-NtGdiSetVirtualResolution 5
-NtGdiSetSizeDevice 3
-NtGdiStartDoc 4
-NtGdiStartPage 1
-NtGdiStretchBlt 12
-NtGdiStretchDIBitsInternal 16
-NtGdiStrokeAndFillPath 1
-NtGdiStrokePath 1
-NtGdiSwapBuffers 1
-NtGdiTransformPoints 5
-NtGdiTransparentBlt 11
-NtGdiUnloadPrinterDriver 2
-NtGdiUnmapMemFont 1
-NtGdiUnrealizeObject 1
-NtGdiUpdateColors 1
-NtGdiWidenPath 1
-NtUserActivateKeyboardLayout 2
-NtUserAlterWindowStyle 3
-NtUserAssociateInputContext 3
-NtUserAttachThreadInput 3
-NtUserBeginPaint 2
-NtUserBitBltSysBmp 8
-NtUserBlockInput 1
-NtUserBuildHimcList 4
-NtUserBuildHwndList 7
-NtUserBuildNameList 4
-NtUserBuildPropList 4
-NtUserCallHwnd 2
-NtUserCallHwndLock 2
-NtUserCallHwndOpt 2
-NtUserCallHwndParam 3
-NtUserCallHwndParamLock 3
-NtUserCallMsgFilter 2
-NtUserCallNextHookEx 4
-NtUserCallNoParam 1
-NtUserCallOneParam 2
-NtUserCallTwoParam 3
-NtUserChangeClipboardChain 2
-NtUserChangeDisplaySettings 5
-NtUserCheckImeHotKey 2
-NtUserCheckMenuItem 3
-NtUserChildWindowFromPointEx 4
-NtUserClipCursor 1
-NtUserCloseClipboard 0
-NtUserCloseDesktop 1
-NtUserCloseWindowStation 1
-NtUserConsoleControl 3
-NtUserConvertMemHandle 2
-NtUserCopyAcceleratorTable 3
-NtUserCountClipboardFormats 0
-NtUserCreateAcceleratorTable 2
-NtUserCreateCaret 4
-NtUserCreateDesktop 5
-NtUserCreateInputContext 1
-NtUserCreateLocalMemHandle 4
-NtUserCreateWindowEx 15
-NtUserCreateWindowStation 7
-NtUserDdeGetQualityOfService 3
-NtUserDdeInitialize 5
-NtUserDdeSetQualityOfService 3
-NtUserDeferWindowPos 8
-NtUserDefSetText 2
-NtUserDeleteMenu 3
-NtUserDestroyAcceleratorTable 1
-NtUserDestroyCursor 2
-NtUserDestroyInputContext 1
-NtUserDestroyMenu 1
-NtUserDestroyWindow 1
-NtUserDisableThreadIme 1
-NtUserDispatchMessage 1
-NtUserDragDetect 3
-NtUserDragObject 5
-NtUserDrawAnimatedRects 4
-NtUserDrawCaption 4
-NtUserDrawCaptionTemp 7
-NtUserDrawIconEx 11
-NtUserDrawMenuBarTemp 5
-NtUserEmptyClipboard 0
-NtUserEnableMenuItem 3
-NtUserEnableScrollBar 3
-NtUserEndDeferWindowPosEx 2
-NtUserEndMenu 0
-NtUserEndPaint 2
-NtUserEnumDisplayDevices 4
-# NtUserEnumDisplayMonitors 4 Wrong number of param ?
-NtUserEnumDisplayMonitors 5
-NtUserEnumDisplaySettings 4
-NtUserEvent 1
-NtUserExcludeUpdateRgn 2
-NtUserFillWindow 4
-# NtUserFindExistingCursorIcon 3 Wrong number of param ?
-NtUserFindExistingCursorIcon 4
-NtUserFindWindowEx 5
-NtUserFlashWindowEx 1
-NtUserGetAltTabInfo 6
-NtUserGetAncestor 2
-NtUserGetAppImeLevel 1
-NtUserGetAsyncKeyState 1
-NtUserGetAtomName 2
-NtUserGetCaretBlinkTime 0
-NtUserGetCaretPos 1
-NtUserGetClassInfo 5
-NtUserGetClassName 3
-NtUserGetClipboardData 2
-NtUserGetClipboardFormatName 3
-NtUserGetClipboardOwner 0
-NtUserGetClipboardSequenceNumber 0
-NtUserGetClipboardViewer 0
-NtUserGetClipCursor 1
-NtUserGetComboBoxInfo 2
-NtUserGetControlBrush 3
-NtUserGetControlColor 4
-NtUserGetCPD 3
-NtUserGetCursorFrameInfo 4
-NtUserGetCursorInfo 1
-NtUserGetDC 1
-NtUserGetDCEx 3
-NtUserGetDoubleClickTime 0
-NtUserGetForegroundWindow 0
-NtUserGetGuiResources 2
-NtUserGetGUIThreadInfo 2
-NtUserGetIconInfo 6
-NtUserGetIconSize 4
-NtUserGetImeHotKey 4
-NtUserGetImeInfoEx 2
-NtUserGetInternalWindowPos 3
-NtUserGetKeyboardLayoutList 2
-NtUserGetKeyboardLayoutName 1
-NtUserGetKeyboardState 1
-NtUserGetKeyNameText 3
-NtUserGetKeyState 1
-NtUserGetListBoxInfo 1
-NtUserGetMenuBarInfo 4
-NtUserGetMenuIndex 2
-NtUserGetMenuItemRect 4
-NtUserGetMessage 4
-NtUserGetMouseMovePointsEx 5
-NtUserGetObjectInformation 5
-NtUserGetOpenClipboardWindow 0
-NtUserGetPriorityClipboardFormat 2
-NtUserGetProcessWindowStation 0
-NtUserGetRawInputBuffer 3
-NtUserGetRawInputData 5
-NtUserGetRawInputDeviceInfo 4
-NtUserGetRawInputDeviceList 3
-NtUserGetRegisteredRawInputDevices 3
-NtUserGetScrollBarInfo 3
-NtUserGetSystemMenu 2
-NtUserGetThreadDesktop 2
-NtUserGetThreadState 1
-NtUserGetTitleBarInfo 2
-NtUserGetUpdateRect 3
-NtUserGetUpdateRgn 3
-NtUserGetWindowDC 1
-NtUserGetWindowPlacement 2
-NtUserGetWOWClass 2
-NtUserHardErrorControl 3
-NtUserHideCaret 1
-NtUserHiliteMenuItem 4
-NtUserImpersonateDdeClientWindow 2
-NtUserInitialize 3
-NtUserInitializeClientPfnArrays 4
-NtUserInitTask 12
-NtUserInternalGetWindowText 3
-NtUserInvalidateRect 3
-NtUserInvalidateRgn 3
-NtUserIsClipboardFormatAvailable 1
-NtUserKillTimer 2
-NtUserLoadKeyboardLayoutEx 7
-NtUserLockWindowStation 1
-NtUserLockWindowUpdate 1
-NtUserLockWorkStation 0
-NtUserMapVirtualKeyEx 4
-NtUserMenuItemFromPoint 4
-NtUserMessageCall 7
-NtUserMinMaximize 3
-NtUserMNDragLeave 0
-NtUserMNDragOver 2
-NtUserModifyUserStartupInfoFlags 2
-NtUserMoveWindow 6
-NtUserNotifyIMEStatus 3
-NtUserNotifyProcessCreate 4
-NtUserNotifyWinEvent 4
-NtUserOpenClipboard 2
-NtUserOpenDesktop 3
-NtUserOpenInputDesktop 3
-NtUserOpenWindowStation 2
-NtUserPaintDesktop 1
-NtUserPeekMessage 5
-NtUserPostMessage 4
-NtUserPostThreadMessage 4
-NtUserPrintWindow 3
-NtUserProcessConnect 3
-NtUserQueryInformationThread 5
-NtUserQueryInputContext 2
-NtUserQuerySendMessage 1
-NtUserQueryUserCounters 5
-NtUserQueryWindow 2
-NtUserRealChildWindowFromPoint 3
-NtUserRealInternalGetMessage 6
-NtUserRealWaitMessageEx 2
-NtUserRedrawWindow 4
-NtUserRegisterClassExWOW 7
-NtUserRegisterUserApiHook 2
-NtUserRegisterHotKey 4
-NtUserRegisterRawInputDevices 3
-NtUserRegisterTasklist 1
-NtUserRegisterWindowMessage 1
-NtUserRemoveMenu 3
-NtUserRemoveProp 2
-NtUserResolveDesktop 4
-NtUserResolveDesktopForWOW 1
-NtUserSBGetParms 4
-NtUserScrollDC 7
-NtUserScrollWindowEx 8
-NtUserSelectPalette 3
-NtUserSendInput 3
-NtUserSetActiveWindow 1
-NtUserSetAppImeLevel 2
-NtUserSetCapture 1
-NtUserSetClassLong 4
-NtUserSetClassWord 3
-NtUserSetClipboardData 3
-NtUserSetClipboardViewer 1
-NtUserSetConsoleReserveKeys 2
-NtUserSetCursor 1
-NtUserSetCursorContents 2
-NtUserSetCursorIconData 6 #4
-NtUserSetDbgTag 2
-NtUserSetFocus 1
-NtUserSetImeHotKey 5
-NtUserSetImeInfoEx 1
-NtUserSetImeOwnerWindow 2
-NtUserSetInformationProcess 4
-NtUserSetInformationThread 4
-NtUserSetInternalWindowPos 4
-NtUserSetKeyboardState 1
-NtUserSetLogonNotifyWindow 1
-NtUserSetMenu 3
-NtUserSetMenuContextHelpId 2
-NtUserSetMenuDefaultItem 3
-NtUserSetMenuFlagRtoL 1
-NtUserSetObjectInformation 4
-NtUserSetParent 2
-NtUserSetProcessWindowStation 1
-NtUserSetProp 3
-NtUserSetRipFlags 2
-NtUserSetScrollInfo 4
-NtUserSetShellWindowEx 2
-NtUserSetSysColors 4
-NtUserSetSystemCursor 2
-NtUserSetSystemMenu 2
-NtUserSetSystemTimer 4
-NtUserSetThreadDesktop 1
-NtUserSetThreadLayoutHandles 2
-NtUserSetThreadState 2
-NtUserSetTimer 4
-NtUserSetWindowFNID 2
-NtUserSetWindowLong 4
-NtUserSetWindowPlacement 2
-NtUserSetWindowPos 7
-NtUserSetWindowRgn 3
-NtUserSetWindowsHookAW 3
-NtUserSetWindowsHookEx 6
-NtUserSetWindowStationUser 4
-NtUserSetWindowWord 3
-NtUserSetWinEventHook 8
-NtUserShowCaret 1
-NtUserShowScrollBar 3
-NtUserShowWindow 2
-NtUserShowWindowAsync 2
-NtUserSoundSentry 0
-NtUserSwitchDesktop 1
-NtUserSystemParametersInfo 4
-NtUserTestForInteractiveUser 1
-NtUserThunkedMenuInfo 2
-NtUserThunkedMenuItemInfo 6
-NtUserToUnicodeEx 7
-NtUserTrackMouseEvent 1
-NtUserTrackPopupMenuEx 6
-NtUserCalcMenuBar 5
-NtUserPaintMenuBar 6
-NtUserTranslateAccelerator 3
-NtUserTranslateMessage 2
-NtUserUnhookWindowsHookEx 1
-NtUserUnhookWinEvent 1
-NtUserUnloadKeyboardLayout 1
-NtUserUnlockWindowStation 1
-NtUserUnregisterClass 3
-NtUserUnregisterUserApiHook 0
-NtUserUnregisterHotKey 2
-NtUserUpdateInputContext 3
-NtUserUpdateInstance 3
-NtUserUpdateLayeredWindow 9
-NtUserGetLayeredWindowAttributes 4
-NtUserSetLayeredWindowAttributes 4
-NtUserUpdatePerUserSystemParameters 2
-NtUserUserHandleGrantAccess 3
-NtUserValidateHandleSecure 2
-NtUserValidateRect 2
-NtUserValidateTimerCallback 3
-NtUserVkKeyScanEx 3
-NtUserWaitForInputIdle 3
-NtUserWaitForMsgAndEvent 1
-NtUserWaitMessage 0
-NtUserWin32PoolAllocationStats 6
-NtUserWindowFromPoint 2
-NtUserYieldTask 0
-NtUserRemoteConnect 3
-NtUserRemoteRedrawRectangle 4
-NtUserRemoteRedrawScreen 0
-NtUserRemoteStopScreenUpdates 0
-NtUserCtxDisplayIOCtl 3
-NtGdiEngAssociateSurface 3
-NtGdiEngCreateBitmap 6
-NtGdiEngCreateDeviceSurface 4
-NtGdiEngCreateDeviceBitmap 4
-NtGdiEngCreatePalette 6
-NtGdiEngComputeGlyphSet 3
-NtGdiEngCopyBits 6
-NtGdiEngDeletePalette 1
-NtGdiEngDeleteSurface 1
-NtGdiEngEraseSurface 3
-NtGdiEngUnlockSurface 1
-NtGdiEngLockSurface 1
-NtGdiEngBitBlt 11
-NtGdiEngStretchBlt 11
-NtGdiEngPlgBlt 11
-NtGdiEngMarkBandingSurface 1
-NtGdiEngStrokePath 8
-NtGdiEngFillPath 7
-NtGdiEngStrokeAndFillPath 10
-NtGdiEngPaint 5
-NtGdiEngLineTo 9
-NtGdiEngAlphaBlend 7
-NtGdiEngGradientFill 10
-NtGdiEngTransparentBlt 8
-NtGdiEngTextOut 10
-NtGdiEngStretchBltROP 13
-NtGdiXLATEOBJ_cGetPalette 4
-NtGdiXLATEOBJ_iXlate 2
-NtGdiXLATEOBJ_hGetColorTransform 1
-NtGdiCLIPOBJ_bEnum 3
-NtGdiCLIPOBJ_cEnumStart 5
-NtGdiCLIPOBJ_ppoGetPath 1
-NtGdiEngDeletePath 1
-NtGdiEngCreateClip 0
-NtGdiEngDeleteClip 1
-NtGdiBRUSHOBJ_ulGetBrushColor 1
-NtGdiBRUSHOBJ_pvAllocRbrush 2
-NtGdiBRUSHOBJ_pvGetRbrush 1
-NtGdiBRUSHOBJ_hGetColorTransform 1
-NtGdiXFORMOBJ_bApplyXform 5
-NtGdiXFORMOBJ_iGetXform 2
-NtGdiFONTOBJ_vGetInfo 3
-NtGdiFONTOBJ_pxoGetXform 1
-NtGdiFONTOBJ_cGetGlyphs 5
-NtGdiFONTOBJ_pifi 1
-NtGdiFONTOBJ_pfdg 1
-NtGdiFONTOBJ_pQueryGlyphAttrs 2
-NtGdiFONTOBJ_pvTrueTypeFontFile 2
-NtGdiFONTOBJ_cGetAllGlyphHandles 2
-NtGdiSTROBJ_bEnum 3
-NtGdiSTROBJ_bEnumPositionsOnly 3
-NtGdiSTROBJ_bGetAdvanceWidths 4
-NtGdiSTROBJ_vEnumStart 1
-NtGdiSTROBJ_dwGetCodePage 1
-NtGdiPATHOBJ_vGetBounds 2
-NtGdiPATHOBJ_bEnum 2
-NtGdiPATHOBJ_vEnumStart 1
-NtGdiPATHOBJ_vEnumStartClipLines 4
-NtGdiPATHOBJ_bEnumClipLines 3
-NtGdiGetDhpdev 1
-NtGdiEngCheckAbort 1
-NtGdiHT_Get8BPPFormatPalette 4
-NtGdiHT_Get8BPPMaskPalette 6
-NtGdiUpdateTransform 1
-NtGdiSetPUMPDOBJ 4
-NtGdiBRUSHOBJ_DeleteRbrush 2
-NtGdiUMPDEngFreeUserMem 1
-NtGdiDrawStream 3
-NtGdiMakeObjectXferable 2
-NtGdiMakeObjectUnXferable 1
+NtGdiAbortDoc 1
+NtGdiAbortPath 1
+NtGdiAddFontResourceW 6
+NtGdiAddRemoteFontToDC 4
+NtGdiAddFontMemResourceEx 5
+NtGdiRemoveMergeFont 2
+NtGdiAddRemoteMMInstanceToDC 3
+NtGdiAlphaBlend 12
+NtGdiAngleArc 6
+NtGdiAnyLinkedFonts 0
+NtGdiFontIsLinked 1
+NtGdiArcInternal 10
+NtGdiBeginPath 1
+NtGdiBitBlt 11
+NtGdiCancelDC 1
+NtGdiCheckBitmapBits 8
+NtGdiCloseFigure 1
+NtGdiClearBitmapAttributes 2
+NtGdiClearBrushAttributes 2
+NtGdiColorCorrectPalette 6
+NtGdiCombineRgn 4
+NtGdiCombineTransform 3
+NtGdiComputeXformCoefficients 1
+NtGdiConsoleTextOut 4
+NtGdiConvertMetafileRect 2
+NtGdiCreateBitmap 5
+NtGdiCreateClientObj 1
+NtGdiCreateColorSpace 1
+NtGdiCreateColorTransform 8
+NtGdiCreateCompatibleBitmap 3
+NtGdiCreateCompatibleDC 1
+NtGdiCreateDIBBrush 6
+NtGdiCreateDIBitmapInternal 11
+NtGdiCreateDIBSection 9
+NtGdiCreateEllipticRgn 4
+NtGdiCreateHalftonePalette 1
+NtGdiCreateHatchBrushInternal 3
+NtGdiCreateMetafileDC 1
+NtGdiCreatePaletteInternal 2
+NtGdiCreatePatternBrushInternal 3
+NtGdiCreatePen 4
+NtGdiCreateRectRgn 4
+NtGdiCreateRoundRectRgn 6
+NtGdiCreateServerMetaFile 6
+NtGdiCreateSolidBrush 2
+NtGdiD3dContextCreate 4
+NtGdiD3dContextDestroy 1
+NtGdiD3dContextDestroyAll 1
+NtGdiD3dValidateTextureStageState 1
+NtGdiD3dDrawPrimitives2 7
+NtGdiDdGetDriverState 1
+NtGdiDdAddAttachedSurface 3
+NtGdiDdAlphaBlt 3
+NtGdiDdAttachSurface 2
+NtGdiDdBeginMoCompFrame 2
+NtGdiDdBlt 3
+NtGdiDdCanCreateSurface 2
+NtGdiDdCanCreateD3DBuffer 2
+NtGdiDdColorControl 2
+NtGdiDdCreateDirectDrawObject 1
+NtGdiDdCreateSurface 8
+NtGdiDdCreateD3DBuffer 8
+NtGdiDdCreateMoComp 2
+NtGdiDdCreateSurfaceObject 6
+NtGdiDdDeleteDirectDrawObject 1
+NtGdiDdDeleteSurfaceObject 1
+NtGdiDdDestroyMoComp 2
+NtGdiDdDestroySurface 2
+NtGdiDdDestroyD3DBuffer 1
+NtGdiDdEndMoCompFrame 2
+NtGdiDdFlip 5
+NtGdiDdFlipToGDISurface 2
+NtGdiDdGetAvailDriverMemory 2
+NtGdiDdGetBltStatus 2
+NtGdiDdGetDC 2
+NtGdiDdGetDriverInfo 2
+NtGdiDdGetDxHandle 3
+NtGdiDdGetFlipStatus 2
+NtGdiDdGetInternalMoCompInfo 2
+NtGdiDdGetMoCompBuffInfo 2
+NtGdiDdGetMoCompGuids 2
+NtGdiDdGetMoCompFormats 2
+NtGdiDdGetScanLine 2
+NtGdiDdLock 3
+NtGdiDdLockD3D 2
+NtGdiDdQueryDirectDrawObject 11
+NtGdiDdQueryMoCompStatus 2
+NtGdiDdReenableDirectDrawObject 2
+NtGdiDdReleaseDC 1
+NtGdiDdRenderMoComp 2
+NtGdiDdResetVisrgn 2
+NtGdiDdSetColorKey 2
+NtGdiDdSetExclusiveMode 2
+NtGdiDdSetGammaRamp 3
+NtGdiDdCreateSurfaceEx 3
+NtGdiDdSetOverlayPosition 3
+NtGdiDdUnattachSurface 2
+NtGdiDdUnlock 2
+NtGdiDdUnlockD3D 2
+NtGdiDdUpdateOverlay 3
+NtGdiDdWaitForVerticalBlank 2
+NtGdiDvpCanCreateVideoPort 2
+NtGdiDvpColorControl 2
+NtGdiDvpCreateVideoPort 2
+NtGdiDvpDestroyVideoPort 2
+NtGdiDvpFlipVideoPort 4
+NtGdiDvpGetVideoPortBandwidth 2
+NtGdiDvpGetVideoPortField 2
+NtGdiDvpGetVideoPortFlipStatus 2
+NtGdiDvpGetVideoPortInputFormats 2
+NtGdiDvpGetVideoPortLine 2
+NtGdiDvpGetVideoPortOutputFormats 2
+NtGdiDvpGetVideoPortConnectInfo 2
+NtGdiDvpGetVideoSignalStatus 2
+NtGdiDvpUpdateVideoPort 4
+NtGdiDvpWaitForVideoPortSync 2
+NtGdiDvpAcquireNotification 3
+NtGdiDvpReleaseNotification 2
+NtGdiDxgGenericThunk 6
+NtGdiDeleteClientObj 1
+NtGdiDeleteColorSpace 1
+NtGdiDeleteColorTransform 2
+NtGdiDeleteObjectApp 1
+NtGdiDescribePixelFormat 4
+NtGdiGetPerBandInfo 2
+NtGdiDoBanding 4
+NtGdiDoPalette 6
+NtGdiDrawEscape 4
+NtGdiEllipse 5
+NtGdiEnableEudc 1
+NtGdiEndDoc 1
+NtGdiEndPage 1
+NtGdiEndPath 1
+NtGdiEnumFontChunk 5
+NtGdiEnumFontClose 1
+NtGdiEnumFontOpen 7
+NtGdiEnumObjects 4
+NtGdiEqualRgn 2
+NtGdiEudcLoadUnloadLink 7
+NtGdiExcludeClipRect 5
+NtGdiExtCreatePen 11
+NtGdiExtCreateRegion 3
+NtGdiExtEscape 8
+NtGdiExtFloodFill 5
+NtGdiExtGetObjectW 3
+NtGdiExtSelectClipRgn 3
+NtGdiExtTextOutW 9
+NtGdiFillPath 1
+NtGdiFillRgn 3
+NtGdiFlattenPath 1
+NtGdiFlush 0
+NtGdiForceUFIMapping 2
+NtGdiFrameRgn 5
+NtGdiFullscreenControl 5
+NtGdiGetAndSetDCDword 4
+NtGdiGetAppClipBox 2
+NtGdiGetBitmapBits 3
+NtGdiGetBitmapDimension 2
+NtGdiGetBoundsRect 3
+NtGdiGetCharABCWidthsW 6
+NtGdiGetCharacterPlacementW 6
+NtGdiGetCharSet 1
+NtGdiGetCharWidthW 6
+NtGdiGetCharWidthInfo 2
+NtGdiGetColorAdjustment 2
+NtGdiGetColorSpaceforBitmap 1
+NtGdiGetDCDword 3
+NtGdiGetDCforBitmap 1
+NtGdiGetDCObject 2
+NtGdiGetDCPoint 3
+NtGdiGetDeviceCaps 2
+NtGdiGetDeviceGammaRamp 2
+NtGdiGetDeviceCapsAll 2
+NtGdiGetDIBitsInternal 9
+NtGdiGetETM 2
+NtGdiGetEudcTimeStampEx 3
+NtGdiGetFontData 5
+NtGdiGetFontResourceInfoInternalW 7
+NtGdiGetGlyphIndicesW 5
+NtGdiGetGlyphIndicesWInternal 6
+NtGdiGetGlyphOutline 8
+NtGdiGetKerningPairs 3
+NtGdiGetLinkedUFIs 3
+NtGdiGetMiterLimit 2
+NtGdiGetMonitorID 3
+NtGdiGetNearestColor 2
+NtGdiGetNearestPaletteIndex 2
+NtGdiGetObjectBitmapHandle 2
+NtGdiGetOutlineTextMetricsInternalW 4
+NtGdiGetPath 4
+NtGdiGetPixel 3
+NtGdiGetRandomRgn 3
+NtGdiGetRasterizerCaps 2
+NtGdiGetRealizationInfo 3
+NtGdiGetRegionData 3
+NtGdiGetRgnBox 2
+NtGdiGetServerMetaFileBits 7
+NtGdiGetSpoolMessage 4
+NtGdiGetStats 5
+NtGdiGetStockObject 1
+NtGdiGetStringBitmapW 5
+NtGdiGetSystemPaletteUse 1
+NtGdiGetTextCharsetInfo 3
+NtGdiGetTextExtent 5
+NtGdiGetTextExtentExW 8
+NtGdiGetTextFaceW 4
+NtGdiGetTextMetricsW 3
+NtGdiGetTransform 3
+NtGdiGetUFI 6
+NtGdiGetEmbUFI 7
+NtGdiGetUFIPathname 10
+NtGdiGetEmbedFonts 0
+NtGdiChangeGhostFont 2
+NtGdiAddEmbFontToDC 2
+NtGdiGetFontUnicodeRanges 2
+NtGdiGetWidthTable 7
+NtGdiGradientFill 6
+NtGdiHfontCreate 5
+NtGdiIcmBrushInfo 8
+NtGdiInit 0
+NtGdiInitSpool 0
+NtGdiIntersectClipRect 5
+NtGdiInvertRgn 2
+NtGdiLineTo 3
+NtGdiMakeFontDir 5
+NtGdiMakeInfoDC 2
+NtGdiMaskBlt 13
+NtGdiModifyWorldTransform 3
+NtGdiMonoBitmap 1
+NtGdiMoveTo 4
+NtGdiOffsetClipRgn 3
+NtGdiOffsetRgn 3
+NtGdiOpenDCW 7
+NtGdiPatBlt 6
+NtGdiPolyPatBlt 5
+NtGdiPathToRegion 1
+NtGdiPlgBlt 11
+NtGdiPolyDraw 4
+NtGdiPolyPolyDraw 5
+NtGdiPolyTextOutW 4
+NtGdiPtInRegion 3
+NtGdiPtVisible 3
+NtGdiQueryFonts 3
+NtGdiQueryFontAssocInfo 1
+NtGdiRectangle 5
+NtGdiRectInRegion 2
+NtGdiRectVisible 2
+NtGdiRemoveFontResourceW 6
+NtGdiRemoveFontMemResourceEx 1
+NtGdiResetDC 5
+NtGdiResizePalette 2
+NtGdiRestoreDC 2
+NtGdiRoundRect 7
+NtGdiSaveDC 1
+NtGdiScaleViewportExtEx 6
+NtGdiScaleWindowExtEx 6
+NtGdiSelectBitmap 2GreSelectBitmap 2
+NtGdiSelectBrush 2
+NtGdiSelectClipPath 2
+NtGdiSelectFont 2
+NtGdiSelectPen 2
+NtGdiSetBitmapAttributes 2
+NtGdiSetBitmapBits 3
+NtGdiSetBitmapDimension 4
+NtGdiSetBoundsRect 3
+NtGdiSetBrushAttributes 2
+NtGdiSetBrushOrg 4
+NtGdiSetColorAdjustment 2
+NtGdiSetColorSpace 2
+NtGdiSetDeviceGammaRamp 2
+NtGdiSetDIBitsToDeviceInternal 16
+NtGdiSetFontEnumeration 1
+NtGdiSetFontXform 3
+NtGdiSetIcmMode 3
+NtGdiSetLinkedUFIs 3
+NtGdiSetMagicColors 3
+NtGdiSetMetaRgn 1
+NtGdiSetMiterLimit 3
+NtGdiGetDeviceWidth 1
+NtGdiMirrorWindowOrg 1
+NtGdiSetLayout 3
+NtGdiSetPixel 4
+NtGdiSetPixelFormat 2
+NtGdiSetRectRgn 5
+NtGdiSetSystemPaletteUse 2
+NtGdiSetTextJustification 3
+NtGdiSetupPublicCFONT 3
+NtGdiSetVirtualResolution 5
+NtGdiSetSizeDevice 3
+NtGdiStartDoc 4
+NtGdiStartPage 1
+NtGdiStretchBlt 12
+NtGdiStretchDIBitsInternal 16
+NtGdiStrokeAndFillPath 1
+NtGdiStrokePath 1
+NtGdiSwapBuffers 1
+NtGdiTransformPoints 5
+NtGdiTransparentBlt 11
+NtGdiUnloadPrinterDriver 2
+NtGdiUMPDEngFreeUserMem 1NtGdiUnmapMemFont 1
+NtGdiUnrealizeObject 1
+NtGdiUpdateColors 1
+NtGdiWidenPath 1
+NtUserActivateKeyboardLayout 2
+NtUserAlterWindowStyle 3
+NtUserAssociateInputContext 3
+NtUserAttachThreadInput 3
+NtUserBeginPaint 2
+NtUserBitBltSysBmp 8
+NtUserBlockInput 1
+NtUserBuildHimcList 4
+NtUserBuildHwndList 7
+NtUserBuildNameList 4
+NtUserBuildPropList 4
+NtUserCallHwnd 2
+NtUserCallHwndLock 2
+NtUserCallHwndOpt 2
+NtUserCallHwndParam 3
+NtUserCallHwndParamLock 3
+NtUserCallMsgFilter 2
+NtUserCallNextHookEx 4
+NtUserCallNoParam 1
+NtUserCallOneParam 2
+NtUserCallTwoParam 3
+NtUserChangeClipboardChain 2
+NtUserChangeDisplaySettings 4
+NtUserCheckImeHotKey 2
+NtUserCheckMenuItem 3
+NtUserChildWindowFromPointEx 4
+NtUserClipCursor 1
+NtUserCloseClipboard 0
+NtUserCloseDesktop 1
+NtUserCloseWindowStation 1
+NtUserConsoleControl 3
+NtUserConvertMemHandle 2
+NtUserCopyAcceleratorTable 3
+NtUserCountClipboardFormats 0
+NtUserCreateAcceleratorTable 2
+NtUserCreateCaret 4
+NtUserCreateDesktop 5
+NtUserCreateInputContext 1
+NtUserCreateLocalMemHandle 4
+NtUserCreateWindowEx 15
+NtUserCreateWindowStation 7
+NtUserDdeGetQualityOfService 3
+NtUserDdeInitialize 5
+NtUserDdeSetQualityOfService 3
+NtUserDeferWindowPos 8
+NtUserDefSetText 2
+NtUserDeleteMenu 3
+NtUserDestroyAcceleratorTable 1
+NtUserDestroyCursor 2
+NtUserDestroyInputContext 1
+NtUserDestroyMenu 1
+NtUserDestroyWindow 1
+NtUserDisableThreadIme 1
+NtUserDispatchMessage 1
+NtUserDragDetect 3
+NtUserDragObject 5
+NtUserDrawAnimatedRects 4
+NtUserDrawCaption 4
+NtUserDrawCaptionTemp 7
+NtUserDrawIconEx 11
+NtUserDrawMenuBarTemp 5
+NtUserEmptyClipboard 0
+NtUserEnableMenuItem 3
+NtUserEnableScrollBar 3
+NtUserEndDeferWindowPosEx 2
+NtUserEndMenu 0
+NtUserEndPaint 2
+NtUserEnumDisplayDevices 4
+NtUserEnumDisplayMonitors 4
+NtUserEnumDisplaySettings 4
+NtUserEvent 1
+NtUserExcludeUpdateRgn 2
+NtUserFillWindow 4
+NtUserFindExistingCursorIcon 3
+NtUserFindWindowEx 5
+NtUserFlashWindowEx 1
+NtUserGetAltTabInfo 6
+NtUserGetAncestor 2
+NtUserGetAppImeLevel 1
+NtUserGetAsyncKeyState 1
+NtUserGetAtomName 2
+NtUserGetCaretBlinkTime 0
+NtUserGetCaretPos 1
+NtUserGetClassInfoEx 5
+NtUserGetClassName 3
+NtUserGetClipboardData 2
+NtUserGetClipboardFormatName 3
+NtUserGetClipboardOwner 0
+NtUserGetClipboardSequenceNumber 0
+NtUserGetClipboardViewer 0
+NtUserGetClipCursor 1
+NtUserGetComboBoxInfo 2
+NtUserGetControlBrush 3
+NtUserGetControlColor 4
+NtUserGetCPD 3
+NtUserGetCursorFrameInfo 4
+NtUserGetCursorInfo 1
+NtUserGetDC 1
+NtUserGetDCEx 3
+NtUserGetDoubleClickTime 0
+NtUserGetForegroundWindow 0
+NtUserGetGuiResources 2
+NtUserGetGUIThreadInfo 2
+NtUserGetIconInfo 6
+NtUserGetIconSize 4
+NtUserGetImeHotKey 4
+NtUserGetImeInfoEx 2
+NtUserGetInternalWindowPos 3
+NtUserGetKeyboardLayoutList 2
+NtUserGetKeyboardLayoutName 1
+NtUserGetKeyboardState 1
+NtUserGetKeyNameText 3
+NtUserGetKeyState 1
+NtUserGetListBoxInfo 1
+NtUserGetMenuBarInfo 4
+NtUserGetMenuIndex 2
+NtUserGetMenuItemRect 4
+NtUserGetMessage 4
+NtUserGetMouseMovePointsEx 5
+NtUserGetObjectInformation 5
+NtUserGetOpenClipboardWindow 0
+NtUserGetPriorityClipboardFormat 2
+NtUserGetProcessWindowStation 0
+NtUserGetRawInputBuffer 3
+NtUserGetRawInputData 5
+NtUserGetRawInputDeviceInfo 4
+NtUserGetRawInputDeviceList 3
+NtUserGetRegisteredRawInputDevices 3
+NtUserGetScrollBarInfo 3
+NtUserGetSystemMenu 2
+NtUserGetThreadDesktop 2
+NtUserGetThreadState 1
+NtUserGetTitleBarInfo 2
+NtUserGetUpdateRect 3
+NtUserGetUpdateRgn 3
+NtUserGetWindowDC 1
+NtUserGetWindowPlacement 2
+NtUserGetWOWClass 2
+NtUserHardErrorControl 3
+NtUserHideCaret 1
+NtUserHiliteMenuItem 4
+NtUserImpersonateDdeClientWindow 2
+NtUserInitialize 3
+NtUserInitializeClientPfnArrays 4
+NtUserInitTask 12
+NtUserInternalGetWindowText 3
+NtUserInvalidateRect 3
+NtUserInvalidateRgn 3
+NtUserIsClipboardFormatAvailable 1
+NtUserKillTimer 2
+NtUserLoadKeyboardLayoutEx 7
+NtUserLockWindowStation 1
+NtUserLockWindowUpdate 1
+NtUserLockWorkStation 0
+NtUserMapVirtualKeyEx 4
+NtUserMenuItemFromPoint 4
+NtUserMessageCall 7
+NtUserMinMaximize 3
+NtUserMNDragLeave 0
+NtUserMNDragOver 2
+NtUserModifyUserStartupInfoFlags 2
+NtUserMoveWindow 6
+NtUserNotifyIMEStatus 3
+NtUserNotifyProcessCreate 4
+NtUserNotifyWinEvent 4
+NtUserOpenClipboard 2
+NtUserOpenDesktop 3
+NtUserOpenInputDesktop 3
+NtUserOpenWindowStation 2
+NtUserPaintDesktop 1
+NtUserPeekMessage 5
+NtUserPostMessage 4
+NtUserPostThreadMessage 4
+NtUserPrintWindow 3
+NtUserProcessConnect 3
+NtUserQueryInformationThread 4
+NtUserQueryInputContext 2
+NtUserQuerySendMessage 1
+NtUserQueryWindow 2
+NtUserRealChildWindowFromPoint 3
+NtUserRealInternalGetMessage 6
+NtUserRealWaitMessageEx 2
+NtUserRedrawWindow 4
+NtUserRegisterClassExWOW 7
+NtUserRegisterUserApiHook 4
+NtUserRegisterHotKey 4
+NtUserRegisterRawInputDevices 3
+NtUserRegisterTasklist 1
+NtUserRegisterWindowMessage 1
+NtUserRemoveMenu 3
+NtUserRemoveProp 2
+NtUserResolveDesktop 4
+NtUserResolveDesktopForWOW 1
+NtUserSBGetParms 4
+NtUserScrollDC 7
+NtUserScrollWindowEx 8
+NtUserSelectPalette 3
+NtUserSendInput 3
+NtUserSetActiveWindow 1
+NtUserSetAppImeLevel 2
+NtUserSetCapture 1
+NtUserSetClassLong 4
+NtUserSetClassWord 3
+NtUserSetClipboardData 3
+NtUserSetClipboardViewer 1
+NtUserSetConsoleReserveKeys 2
+NtUserSetCursor 1
+NtUserSetCursorContents 2
+NtUserSetCursorIconData 4
+NtUserSetFocus 1
+NtUserSetImeHotKey 5
+NtUserSetImeInfoEx 1
+NtUserSetImeOwnerWindow 2
+NtUserSetInformationProcess 4
+NtUserSetInformationThread 4
+NtUserSetInternalWindowPos 4
+NtUserSetKeyboardState 1
+NtUserSetLogonNotifyWindow 1
+NtUserSetMenu 3
+NtUserSetMenuContextHelpId 2
+NtUserSetMenuDefaultItem 3
+NtUserSetMenuFlagRtoL 1
+NtUserSetObjectInformation 4
+NtUserSetParent 2
+NtUserSetProcessWindowStation 1
+NtUserSetProp 3
+NtUserSetScrollInfo 4
+NtUserSetShellWindowEx 2
+NtUserSetSysColors 4
+NtUserSetSystemCursor 2
+NtUserSetSystemMenu 2
+NtUserSetSystemTimer 4
+NtUserSetThreadDesktop 1
+NtUserSetThreadLayoutHandles 2
+NtUserSetThreadState 2
+NtUserSetTimer 4
+NtUserSetWindowFNID 2
+NtUserSetWindowLong 4
+NtUserSetWindowPlacement 2
+NtUserSetWindowPos 7
+NtUserSetWindowRgn 3
+NtUserSetWindowsHookAW 3
+NtUserSetWindowsHookEx 6
+NtUserSetWindowStationUser 4
+NtUserSetWindowWord 3
+NtUserSetWinEventHook 8
+NtUserShowCaret 1
+NtUserShowScrollBar 3
+NtUserShowWindow 2
+NtUserShowWindowAsync 2
+NtUserSoundSentry 0
+NtUserSwitchDesktop 1
+NtUserSystemParametersInfo 4
+NtUserTestForInteractiveUser 1
+NtUserThunkedMenuInfo 2
+NtUserThunkedMenuItemInfo 6
+NtUserToUnicodeEx 7
+NtUserTrackMouseEvent 1
+NtUserTrackPopupMenuEx 6
+NtUserCalcMenuBar 5
+NtUserPaintMenuBar 6
+NtUserTranslateAccelerator 3
+NtUserTranslateMessage 2
+NtUserUnhookWindowsHookEx 1
+NtUserUnhookWinEvent 1
+NtUserUnloadKeyboardLayout 1
+NtUserUnlockWindowStation 1
+NtUserUnregisterClass 3
+NtUserUnregisterUserApiHook 0
+NtUserUnregisterHotKey 2
+NtUserUpdateInputContext 3
+NtUserUpdateInstance 3
+NtUserUpdateLayeredWindow 10
+NtUserGetLayeredWindowAttributes 4
+NtUserSetLayeredWindowAttributes 4
+NtUserUpdatePerUserSystemParameters 2
+NtUserUserHandleGrantAccess 3
+NtUserValidateHandleSecure 1
+NtUserValidateRect 2
+NtUserValidateTimerCallback 1
+NtUserVkKeyScanEx 3
+NtUserWaitForInputIdle 3
+NtUserWaitForMsgAndEvent 1
+NtUserWaitMessage 0
+NtUserWin32PoolAllocationStats 6
+NtUserWindowFromPoint 2
+NtUserYieldTask 0
+NtUserRemoteConnect 3
+NtUserRemoteRedrawRectangle 4
+NtUserRemoteRedrawScreen 0
+NtUserRemoteStopScreenUpdates 0
+NtUserCtxDisplayIOCtl 3
+NtGdiEngAssociateSurface 3
+NtGdiEngCreateBitmap 6
+NtGdiEngCreateDeviceSurface 4
+NtGdiEngCreateDeviceBitmap 4
+NtGdiEngCreatePalette 6
+NtGdiEngComputeGlyphSet 3
+NtGdiEngCopyBits 6
+NtGdiEngDeletePalette 1
+NtGdiEngDeleteSurface 1
+NtGdiEngEraseSurface 3
+NtGdiEngUnlockSurface 1
+NtGdiEngLockSurface 1
+NtGdiEngBitBlt 11
+NtGdiEngStretchBlt 11
+NtGdiEngPlgBlt 11
+NtGdiEngMarkBandingSurface 1
+NtGdiEngStrokePath 8
+NtGdiEngFillPath 7
+NtGdiEngStrokeAndFillPath 10
+NtGdiEngPaint 5
+NtGdiEngLineTo 9
+NtGdiEngAlphaBlend 7
+NtGdiEngGradientFill 10
+NtGdiEngTransparentBlt 8
+NtGdiEngTextOut 10
+NtGdiEngStretchBltROP 13
+NtGdiXLATEOBJ_cGetPalette 4
+NtGdiXLATEOBJ_iXlate 2
+NtGdiXLATEOBJ_hGetColorTransform 1
+NtGdiCLIPOBJ_bEnum 3
+NtGdiCLIPOBJ_cEnumStart 5
+NtGdiCLIPOBJ_ppoGetPath 1
+NtGdiEngDeletePath 1
+NtGdiEngCreateClip 0
+NtGdiEngDeleteClip 1
+NtGdiBRUSHOBJ_ulGetBrushColor 1
+NtGdiBRUSHOBJ_pvAllocRbrush 2
+NtGdiBRUSHOBJ_pvGetRbrush 1
+NtGdiBRUSHOBJ_hGetColorTransform 1
+NtGdiXFORMOBJ_bApplyXform 5
+NtGdiXFORMOBJ_iGetXform 2
+NtGdiFONTOBJ_vGetInfo 3
+NtGdiFONTOBJ_pxoGetXform 1
+NtGdiFONTOBJ_cGetGlyphs 5
+NtGdiFONTOBJ_pifi 1
+NtGdiFONTOBJ_pfdg 1
+NtGdiFONTOBJ_pQueryGlyphAttrs 2
+NtGdiFONTOBJ_pvTrueTypeFontFile 2
+NtGdiFONTOBJ_cGetAllGlyphHandles 2
+NtGdiSTROBJ_bEnum 3
+NtGdiSTROBJ_bEnumPositionsOnly 3
+NtGdiSTROBJ_bGetAdvanceWidths 4
+NtGdiSTROBJ_vEnumStart 1
+NtGdiSTROBJ_dwGetCodePage 1
+NtGdiPATHOBJ_vGetBounds 2
+NtGdiPATHOBJ_bEnum 2
+NtGdiPATHOBJ_vEnumStart 1
+NtGdiPATHOBJ_vEnumStartClipLines 4
+NtGdiPATHOBJ_bEnumClipLines 3
+NtGdiGetDhpdev 1
+NtGdiEngCheckAbort 1
+NtGdiHT_Get8BPPFormatPalette 4
+NtGdiHT_Get8BPPMaskPalette 6
+NtGdiUpdateTransform 1
+NtGdiSetPUMPDOBJ 4
+NtGdiBRUSHOBJ_DeleteRbrush 2
+NtGdiUMPDEngFreeUserMem 1
+NtGdiUnmapMemFont 1
+NtGdiDrawStream 3
+UMPDDrvQuerySpoolType 2
+NtGdiMakeObjectXferable 2
+NtGdiMakeObjectUnXferable 1
+DefaultHTCallBack 1
+DxEngGetRedirectionBitmap 1
Modified: branches/nwin32/subsystems/win32/win32k/win32k.rbuild
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/win32k.rbuild [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/win32k.rbuild [iso-8859-1] Mon Jul 28 06:32:04
2008
@@ -54,6 +54,7 @@
<file>gdistubs.c</file>
</directory>
<directory name="ntuser">
+ <file>usrfuncs.c</file>
<file>usrstubs.c</file>
</directory>
<file>win32k.rc</file>
Modified: branches/nwin32/subsystems/win32/win32k/win32k_vc9.vcproj
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
==============================================================================
--- branches/nwin32/subsystems/win32/win32k/win32k_vc9.vcproj [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/win32k_vc9.vcproj [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -773,6 +773,10 @@
Name="ntuser"
<File
+ RelativePath=".\ntuser\usrfuncs.c"
+ >
+ </File>
+ <File
RelativePath=".\ntuser\usrstubs.c"
</File>
--- branches/nwin32/subsystems/win32/win32k/ntgdi/gdifuncs.c [iso-8859-1] (original)
+++ branches/nwin32/subsystems/win32/win32k/ntgdi/gdifuncs.c [iso-8859-1] Mon Jul 28
06:32:04 2008
@@ -1,8 +1,8 @@
/*
* PROJECT: ReactOS Win32K
* LICENSE: GPL - See COPYING in the top level directory
* FILE: subsystems/win32/win32k/ntgdi/gdistubs.c
* PURPOSE: Syscall stubs
* PROGRAMMERS: Aleksey Bragin (aleksey(a)reactos.org)
*/
@@ -23,3 +23,23 @@
return TRUE;
}
+W32KAPI
+ULONG
+APIENTRY
+NtGdiQueryFontAssocInfo(IN HDC hdc)
+{
+ UNIMPLEMENTED;
+ return 0;
+}
+
+W32KAPI
+HANDLE
+APIENTRY
+NtGdiGetStockObject(IN INT Object)
+{
+ DPRINT1("NtGdiGetStockObject() index %d\n", Object);
+
+ /* TODO: Return the requested stock object*/
+ return NULL;
+}
+
Modified: branches/nwin32/subsystems/win32/win32k/ntgdi/gdistubs.c
URL:
http://svn.reactos.org/svn/reactos/branches/nwin32/subsystems/win32/win32k/…
@@ -1,8 +1,8 @@
* PROJECT: ReactOS Win32K
* LICENSE: GPL - See COPYING in the top level directory
- * FILE: subsystems/win32/win32k/ntgdi/gdistubs.c
- * PURPOSE: Syscall stubs
+ * FILE: subsystems/win32/win32k/ntgdi/gdifuncs.c
+ * PURPOSE: GDI functions
* PROGRAMMERS: Aleksey Bragin (aleksey(a)reactos.org)
*/
==============================================================================